# Contributors

* Blair Subbaraman [b1air@uw.edu](mailto:b1air@uw.edu)
* Maria Politi [politim@uw.edu](mailto:politim@uw.edu)
* Brenden Pelkie [bgpelkie@uw.edu](mailto:bgpelkie@uw.edu)
* Sterling G. Baird [sterling.baird@utoronto.ca](mailto:sterling.baird@utoronto.ca)
